from transformers import pipeline

pipe = pipeline()

def create_model(model_name: str):
    return_model = pipeline(
        "text-generation",
        model=model_name
    )

    return return_model

def generate_response(model: str, message: str, max_tokens: int, temperature: float):
    response = model(
        message,
        max_new_tokens=max_tokens,
        temperature=temperature
    )

    return response


from setuptools import setup, find_packages

setup(
    name="genai_pygame",
    description='A helpful PyGame tool for intergrating Generative AI models into game projects.',
    author='Alex Khon',
    author_email='alexoverkode@hotmail.com',
    version="0.1.3",
    packages=find_packages(),
    install_requires=[
        'transformers'
    ],
)